function compressionCalculator(shellThickness,capsuleRadius,indenterRadius,poissonsRatio)
%Inputs:
% shellThickness: thickness of capsule shell in nm
% capsuleRadius:  radius of capsule/particle in um
% indenterRadius: radius of indenter in um (if flat, enter a number much larger than the capsule radius)
% poissonsRatio: Poisson's ratio

capsuleRadius = capsuleRadius*1e3; %Convert from um to nm
indenterRadius = indenterRadius*1e3; %Convert from um to nm

shellThicknessRatio = shellThickness/capsuleRadius; %Calculate h/R
indenterRadiusRatio = indenterRadius/capsuleRadius; %Calculate Rp/R

%Check user inputs for problems
if poissonsRatio < 0.1 || poissonsRatio > 0.4
    error('The Poisson`s ratio is outside the simulated range of 0.1 to 0.4. Try setting your Poisson`s ratio to 0.1 if too small or 0.4 if too big, though proceed with caution. There is little dependence upon the Poisson`s ratio inside the simulated range, but this may not be true for values < 0.1 (but most probably true for values > 0.4).')
end

if shellThicknessRatio > 1.
    error('The shell thickness is greater than the capsule radius');
elseif shellThicknessRatio == 1.
    warning('The shell thickness is equal to the capsule radius - is this a solid particle? You are perhaps better off using the analytical expression in Glaubitz et al 2014, or Eq.3 in Berry et al 2017');
elseif shellThicknessRatio < 1e-2
    fprintf('Very thin capsule: Use Reissner`s equation (alpha = beta = 1) with a correction factor C=0.5\n')
    return;
end

if indenterRadiusRatio < 0.02
    error('The indenter is too small in comparison to the particle for the current simulation data available. Either: a) use a bigger indenter, or run a simulation to extract the correct parameters.')
end

if indenterRadiusRatio > 100.
    warning('The indenter radius is much greater than the capsule radius, so setting indenterRadiusRatio = 100. This will not affect the results, as the parameters are independent of the indenter radius ratio for large values of indenter radius ratio.');
    indenterRadiusRatio = 100.;
end

% Print input data to screen
fprintf('-----------------------------\n');
fprintf('User input\n');
fprintf('-----------------------------\n');
fprintf('shell thickness: %f nm\n',shellThickness);
fprintf('Capsule radius: %f nm\n', capsuleRadius);
fprintf('Indenter radius: %f nm\n', indenterRadius);
fprintf('Poisson`s ratio: %f\n', poissonsRatio);
fprintf('-----------------------------\n');
fprintf('Non-dimensional inputs\n');
fprintf('-----------------------------\n');
fprintf('h/R: %f\n',shellThicknessRatio);
fprintf('Rp/R: %f\n',indenterRadiusRatio);

%x -> h/R
%y -> Ri/R
%z -> nu
nu = [0.1,0.2,0.3,0.4]; %Define Poisson's ratio array

%Define interpolation coordinates  (in log-log space)
xq = log10(shellThicknessRatio); 
yq = log10(indenterRadiusRatio);

h_vector = linspace(-2,0,41); %Shell thickness ratio range
Rp_vector = linspace(-1.69897,2,38); %Probe radius ratio range

[xGrid,yGrid] = ...
meshgrid(h_vector,Rp_vector); %Make interpolation grid


dat = simData; %Read in simulation data
N = length(dat)/4;

%Load simulation data, and interpolate data at each Poisson's ratio for
%user inputted h/R, Rp/R (shellThicknessRatio, indenterRadiusRatio)
for i=1:4 %loop over nu=0.1,0.2,0.3,0.4
    startIndex = (i-1)*N+1;
    endIndex = i*N;
    x = log10(dat(startIndex:endIndex,1)); %log(h/R), log of shell thickness ratio
    y = log10(dat(startIndex:endIndex,2)); % log(Rp/R)
    z = dat(startIndex:endIndex,3); % nu, Poisson's ratio
    C = dat(startIndex:endIndex,4); %C, correction factor
    exp = dat(startIndex:endIndex,5); %Scaling exponent
    coeff = dat(startIndex:endIndex,6); %Scaling coefficient
       
    CGrid = griddata(x,y,C,xGrid,yGrid); %Correction factor C on interpolation grid
    CInterp = griddedInterpolant(xGrid',yGrid',CGrid'); %Define interpolant for gridded C data
    COutput(i) = CInterp(xq,yq); %Define C at user input coordinates for each Poisson's ratio
    
    expGrid = griddata(x,y,exp,xGrid,yGrid); %Scaling exponent alpha on interpolation grid
    expInterp = griddedInterpolant(xGrid',yGrid',expGrid'); %Define interpolant for gridded alpha data
    expOutput(i) = expInterp(xq,yq); %Define alpha at user input coordinates for each Poisson's ratio
    
    coeffGrid = griddata(x,y,coeff,xGrid,yGrid); %Scaling coefficient beta on interpolation grid
    coeffInterp = griddedInterpolant(xGrid',yGrid',coeffGrid'); %Define interpolant for gridded beta data
    coeffOutput(i) = coeffInterp(xq,yq); %Define beta at user input coordinates for each Poisson's ratio
    end
end

%Now interpolate in nu to find the final value
CFinal = interp1(nu,COutput,poissonsRatio);
expFinal = interp1(nu,expOutput,poissonsRatio);
coeffFinal = interp1(nu,coeffOutput,poissonsRatio);

%Output to screen
fprintf('-----------------------------\n');
fprintf('Output parameters\n');
fprintf('-----------------------------\n');
fprintf('Correction factor C: %.2f\n',CFinal);
fprintf('Scaling exponent alpha: %.2f\n',expFinal);
fprintf('Scaling coefficient beta: %.2f\n',coeffFinal);
fprintf('-----------------------------\n');

end

% Simulation data
function out = simData
% Shell thickness ratio h/R, Indenter radius ratio Rp/R, Poisson's ratio
% nu, C, alpha, beta
out = [
0.010000	0.020000	0.100000	0.525658	1.033443	0.957467
0.020000	0.020000	0.100000	0.539384	1.064746	0.926083
0.060000	0.020000	0.100000	0.616063	1.192207	0.868146
0.100000	0.020000	0.100000	0.672978	1.291849	0.815644
0.140000	0.020000	0.100000	0.709610	1.356542	0.733081
0.200000	0.020000	0.100000	0.740740	1.433723	0.642758
0.300000	0.020000	0.100000	0.763274	1.492118	0.483408
0.500000	0.020000	0.100000	0.776379	1.5     	0.260221
1.000000	0.020000	0.100000	0.780097	1.5     	0.096346
0.010000	0.100000	0.100000	0.517774	1.022181	0.975135
0.020000	0.100000	0.100000	0.521105	1.043181	0.958333
0.060000	0.100000	0.100000	0.560539	1.136147	0.947685
0.100000	0.100000	0.100000	0.595108	1.225736	0.969962
0.140000	0.100000	0.100000	0.620867	1.298702	0.977288
0.200000	0.100000	0.100000	0.646002	1.377610	0.940729
0.300000	0.100000	0.100000	0.666969	1.451672	0.799029
0.500000	0.100000	0.100000	0.680680	1.50    	0.518011
1.000000	0.100000	0.100000	0.684827	1.5     	0.208067
0.010000	1.000000	0.100000	0.509673	1.021810	1.007797
0.020000	1.000000	0.100000	0.506356	1.038064	1.010009
0.060000	1.000000	0.100000	0.514801	1.096241	1.024853
0.100000	1.000000	0.100000	0.523735	1.160957	1.079678
0.140000	1.000000	0.100000	0.531262	1.222905	1.146627
0.200000	1.000000	0.100000	0.539641	1.302956	1.230915
0.300000	1.000000	0.100000	0.547890	1.397140	1.263067
0.500000	1.000000	0.100000	0.554293	1.485190	1.039644
1.000000	1.000000	0.100000	0.556431	1.5     	0.466681
0.010000	5.000000	0.100000	0.502243	1.040357	1.063268
0.020000	5.000000	0.100000	0.500990	1.054759	1.071545
0.060000	5.000000	0.100000	0.501870	1.092080	1.069596
0.100000	5.000000	0.100000	0.502955	1.146163	1.125079
0.140000	5.000000	0.100000	0.503883	1.201759	1.203169
0.200000	5.000000	0.100000	0.504941	1.278115	1.322571
0.300000	5.000000	0.100000	0.506162	1.375456	1.438742
0.500000	5.000000	0.100000	0.507364	1.476058	1.310481
1.000000	5.000000	0.100000	0.507807	1.5     	0.623621
0.010000	100.000000	0.100000	0.499996	1.037552	1.035073
0.020000	100.000000	0.100000	0.499985	1.037552	1.035073
0.060000	100.000000	0.100000	0.499905	1.092253	1.079227
0.100000	100.000000	0.100000	0.499827	1.144372	1.133735
0.140000	100.000000	0.100000	0.499732	1.198824	1.212988
0.200000	100.000000	0.100000	0.499603	1.274391	1.337287
0.300000	100.000000	0.100000	0.499617	1.371991	1.467263
0.500000	100.000000	0.100000	0.499866	1.474562	1.359118
1.000000	100.000000	0.100000	0.500000	1.5     	0.653218
0.010000	0.020000	0.200000	0.525155	1.033090	0.957433
0.020000	0.020000	0.200000	0.539121	1.064065	0.925795
0.060000	0.020000	0.200000	0.616321	1.189660	0.863183
0.100000	0.020000	0.200000	0.673991	1.286499	0.801907
0.140000	0.020000	0.200000	0.711221	1.348009	0.710732
0.200000	0.020000	0.200000	0.742896	1.424011	0.617439
0.300000	0.020000	0.200000	0.765857	1.484322	0.466227
0.500000	0.020000	0.200000	0.779206	1.50    	0.251458
1.000000	0.020000	0.200000	0.782976	1.5         0.092569
0.010000	0.100000	0.200000	0.517296	1.021922	0.975039
0.020000	0.100000	0.200000	0.520847	1.042688	0.958286
0.060000	0.100000	0.200000	0.560292	1.134758	0.947460
0.100000	0.100000	0.200000	0.595065	1.223610	0.968998
0.140000	0.100000	0.200000	0.621116	1.296015	0.975328
0.200000	0.100000	0.200000	0.646657	1.374312	0.937215
0.300000	0.100000	0.200000	0.668087	1.447763	0.793953
0.500000	0.100000	0.200000	0.682173	1.50    	0.512797
1.000000	0.100000	0.200000	0.686419	1.5     	0.205031
0.010000	1.000000	0.200000	0.509322	1.021335	1.006823
0.020000	1.000000	0.200000	0.506234	1.037332	1.008803
0.060000	1.000000	0.200000	0.514662	1.095033	1.024463
0.100000	1.000000	0.200000	0.523592	1.159357	1.080626
0.140000	1.000000	0.200000	0.531150	1.221129	1.149711
0.200000	1.000000	0.200000	0.539617	1.301299	1.238613
0.300000	1.000000	0.200000	0.548045	1.396206	1.279403
0.500000	1.000000	0.200000	0.554667	1.485556	1.062989
1.000000	1.000000	0.200000	0.556875	1.5     	0.479002
0.010000	5.000000	0.200000	0.502163	1.038920	1.059718
0.020000	5.000000	0.200000	0.500964	1.053161	1.067803
0.060000	5.000000	0.200000	0.501830	1.090694	1.068088
0.100000	5.000000	0.200000	0.502895	1.144523	1.125335
0.140000	5.000000	0.200000	0.503805	1.199985	1.205993
0.200000	5.000000	0.200000	0.504851	1.276512	1.331302
0.300000	5.000000	0.200000	0.506106	1.374775	1.460644
0.500000	5.000000	0.200000	0.507388	1.477262	1.348887
1.000000	5.000000	0.200000	0.507861	1.5     	0.646475
0.010000	100.000000	0.200000	0.499995	1.036859	1.033462
0.020000	100.000000	0.200000	0.499981	1.036859	1.033462
0.060000	100.000000	0.200000	0.499883	1.090813	1.077431
0.100000	100.000000	0.200000	0.499783	1.142712	1.133804
0.140000	100.000000	0.200000	0.499665	1.197040	1.215689
0.200000	100.000000	0.200000	0.499510	1.272781	1.346052
0.300000	100.000000	0.200000	0.499533	1.371328	1.489928
0.500000	100.000000	0.200000	0.499837	1.475874	1.400240
1.000000	100.000000	0.200000	0.500000	1.5     	0.677913
0.010000	0.020000	0.300000	0.524310	1.032489	0.957399
0.020000	0.020000	0.300000	0.538590	1.062923	0.925407
0.060000	0.020000	0.300000	0.616196	1.185683	0.856603
0.100000	0.020000	0.300000	0.674717	1.278676	0.784317
0.140000	0.020000	0.300000	0.712709	1.335975	0.682812
0.200000	0.020000	0.300000	0.745126	1.410560	0.586614
0.300000	0.020000	0.300000	0.768710	1.473633	0.445901
0.500000	0.020000	0.300000	0.782458	1.497343	0.241330
1.000000	0.020000	0.300000	0.786316	1.50    	0.088182
0.010000	0.100000	0.300000	0.516517	1.021486	0.974820
0.020000	0.100000	0.300000	0.520399	1.041862	0.957996
0.060000	0.100000	0.300000	0.559715	1.132412	0.946228
0.100000	0.100000	0.300000	0.594641	1.219994	0.966063
0.140000	0.100000	0.300000	0.621004	1.291450	0.970571
0.200000	0.100000	0.300000	0.647047	1.368758	0.930080
0.300000	0.100000	0.300000	0.669106	1.441289	0.784950
0.500000	0.100000	0.300000	0.683740	1.494079	0.504569
1.000000	0.100000	0.300000	0.688137	1.5     	0.200453
0.010000	1.000000	0.300000	0.508756	1.020564	1.005169
0.020000	1.000000	0.300000	0.506034	1.036157	1.006595
0.060000	1.000000	0.300000	0.514417	1.093031	1.022327
0.100000	1.000000	0.300000	0.523305	1.156573	1.078869
0.140000	1.000000	0.300000	0.530872	1.217828	1.149117
0.200000	1.000000	0.300000	0.539425	1.297765	1.241522
0.300000	1.000000	0.300000	0.548075	1.393149	1.290650
0.500000	1.000000	0.300000	0.554997	1.483869	1.083453
1.000000	1.000000	0.300000	0.557304	1.5     	0.489959
0.010000	5.000000	0.300000	0.502030	1.036632	1.054000
0.020000	5.000000	0.300000	0.500922	1.050646	1.061627
0.060000	5.000000	0.300000	0.501768	1.088447	1.064104
0.100000	5.000000	0.300000	0.502802	1.141722	1.122196
0.140000	5.000000	0.300000	0.503680	1.196745	1.204337
0.200000	5.000000	0.300000	0.504704	1.273078	1.334029
0.300000	5.000000	0.300000	0.506003	1.371972	1.475632
0.500000	5.000000	0.300000	0.507397	1.476409	1.383293
1.000000	5.000000	0.300000	0.507906	1.5     	0.667712
0.010000	100.000000	0.300000	0.499993	1.035722	1.030518
0.020000	100.000000	0.300000	0.499977	1.035722	1.030518
0.060000	100.000000	0.300000	0.499854	1.088488	1.072990
0.100000	100.000000	0.300000	0.499726	1.139890	1.130341
0.140000	100.000000	0.300000	0.499571	1.193795	1.213756
0.200000	100.000000	0.300000	0.499379	1.269350	1.348613
0.300000	100.000000	0.300000	0.499418	1.368541	1.505320
0.500000	100.000000	0.300000	0.499799	1.475123	1.437097
1.000000	100.000000	0.300000	0.500000	1.5     	0.700793
0.010000	0.020000	0.400000	0.523120	1.031611	0.957321
0.020000	0.020000	0.400000	0.537771	1.061263	0.924808
0.060000	0.020000	0.400000	0.615702	1.180002	0.847646
0.100000	0.020000	0.400000	0.675224	1.267699	0.761124
0.140000	0.020000	0.400000	0.714194	1.319368	0.647126
0.200000	0.020000	0.400000	0.747607	1.392165	0.548110
0.300000	0.020000	0.400000	0.772049	1.458987	0.420534
0.500000	0.020000	0.400000	0.786382	1.484830	0.228675
1.000000	0.020000	0.400000	0.790371	1.488754	0.082740
0.010000	0.100000	0.400000	0.515437	1.020857	0.974435
0.020000	0.100000	0.400000	0.519749	1.040666	0.957376
0.060000	0.100000	0.400000	0.558774	1.128987	0.943690
0.100000	0.100000	0.400000	0.593805	1.214658	0.960518
0.140000	0.100000	0.400000	0.620506	1.284656	0.961955
0.200000	0.100000	0.400000	0.647167	1.360450	0.917738
0.300000	0.100000	0.400000	0.670066	1.431567	0.770020
0.500000	0.100000	0.400000	0.685467	1.483361	0.491491
1.000000	0.100000	0.400000	0.690076	1.499823	0.193442
0.010000	1.000000	0.400000	0.507981	1.019489	1.002793
0.020000	1.000000	0.400000	0.505753	1.034515	1.003288
0.060000	1.000000	0.400000	0.514048	1.090158	1.018184
0.100000	1.000000	0.400000	0.522850	1.152467	1.073946
0.140000	1.000000	0.400000	0.530399	1.212815	1.144176
0.200000	1.000000	0.400000	0.539028	1.292075	1.238500
0.300000	1.000000	0.400000	0.547960	1.387589	1.295048
0.500000	1.000000	0.400000	0.555286	1.479630	1.098839
1.000000	1.000000	0.400000	0.557725	1.5     	0.498143
0.010000	5.000000	0.400000	0.501845	1.033535	1.046213
0.020000	5.000000	0.400000	0.500865	1.047230	1.053041
0.060000	5.000000	0.400000	0.501683	1.085274	1.057396
0.100000	5.000000	0.400000	0.502667	1.137648	1.115229
0.140000	5.000000	0.400000	0.503493	1.191876	1.197546
0.200000	5.000000	0.400000	0.504477	1.267584	1.329668
0.300000	5.000000	0.400000	0.505837	1.366720	1.481857
0.500000	5.000000	0.400000	0.507385	1.473055	1.411092
1.000000	5.000000	0.400000	0.507941	1.5     	0.685526
0.010000	100.000000	0.400000	0.499992	1.034141	1.026199
0.020000	100.000000	0.400000	0.499971	1.034141	1.026199
0.060000	100.000000	0.400000	0.499816	1.085214	1.065653
0.100000	100.000000	0.400000	0.499646	1.135796	1.122906
0.140000	100.000000	0.400000	0.499437	1.188931	1.206530
0.200000	100.000000	0.400000	0.499190	1.263867	1.343847
0.300000	100.000000	0.400000	0.499257	1.363310	1.511564
0.500000	100.000000	0.400000	0.499749	1.471873	1.466985
1.000000	100.000000	0.400000	0.500000	1.5     	0.719891];
end
